@@ -1,5 +1,6 @@
-use clap::{crate_version, ArgEnum, Args, Parser, Subcommand};
+use clap::{crate_version, Args, Parser, Subcommand, ValueEnum};
 use std::path::PathBuf;
+#[cfg(feature = "lint")]
 use url::Url;
 
 #[derive(Clone, Parser)]
@@ -7,7 +8,7 @@ use url::Url;
 #[clap(bin_name = "taplo")]
 #[clap(version = crate_version!())]
 pub struct TaploArgs {
-    #[clap(long, arg_enum, global = true, default_value = "auto")]
+    #[clap(long, value_enum, global = true, default_value = "auto")]
     pub colors: Colors,
     /// Enable a verbose logging format.
     #[clap(long, global = true)]
@@ -34,7 +35,7 @@ pub struct GeneralArgs {
     pub no_auto_config: bool,
 }
 
-#[derive(Clone, Copy, ArgEnum)]
+#[derive(Clone, Copy, ValueEnum)]
 pub enum Colors {
     /// Determine whether to colorize output automatically.
     Auto,
@@ -48,28 +49,39 @@ pub enum Colors {
 pub enum TaploCommand {
     /// Lint TOML documents.
     #[clap(visible_aliases = &["check", "validate"])]
+    #[cfg(feature = "lint")]
     Lint(LintCommand),
+
     /// Format TOML documents.
     ///
     /// Files are modified in-place unless the input comes from the standard input, in which case the formatted result is printed to the standard output.
     #[clap(visible_aliases = &["fmt"])]
     Format(FormatCommand),
+
     /// Language server operations.
+    #[cfg(feature = "lsp")]
     Lsp {
         #[clap(flatten)]
         cmd: LspCommand,
     },
+
     /// Operations with the Taplo config file.
     #[clap(visible_aliases = &["cfg"])]
     Config {
         #[clap(subcommand)]
         cmd: ConfigCommand,
     },
+
     /// Extract a value from the given TOML document.
     Get(GetCommand),
+
     /// Start a decoder for `toml-test` (https://github.com/BurntSushi/toml-test).
     #[cfg(feature = "toml-test")]
     TomlTest {},
+
+    /// Generate completions for Taplo CLI
+    #[cfg(feature = "completions")]
+    Completions { shell: String },
 }
 
 #[derive(Clone, Args)]
@@ -108,6 +120,7 @@ pub struct FormatCommand {
     pub stdin_filepath: Option<String>,
 }
 
+#[cfg(feature = "lsp")]
 #[derive(Clone, Args)]
 pub struct LspCommand {
     #[clap(flatten)]
@@ -117,6 +130,7 @@ pub struct LspCommand {
     pub io: LspCommandIo,
 }
 
+#[cfg(feature = "lsp")]
 #[derive(Clone, Subcommand)]
 pub enum LspCommandIo {
     /// Run the language server and listen on a TCP address.
@@ -137,6 +151,7 @@ pub enum ConfigCommand {
     Schema,
 }
 
+#[cfg(feature = "lint")]
 #[derive(Clone, Args)]
 pub struct LintCommand {
     #[clap(flatten)]
@@ -190,7 +205,7 @@ pub struct GetCommand {
     /// Comments and formatting will not be preserved.
     /// It is possible to select arrays and individual values that are not tables,
     /// in this case the output will not be a valid TOML document.
-    #[clap(short, long, arg_enum, default_value = "value")]
+    #[clap(short, long, value_enum, default_value = "value")]
     pub output_format: OutputFormat,
 
     /// Strip the trailing newline from the output.
@@ -229,7 +244,7 @@ pub struct GetCommand {
     pub separator: Option<String>,
 }
 
-#[derive(Clone, Copy, ArgEnum)]
+#[derive(Clone, Copy, ValueEnum)]
 pub enum OutputFormat {
     /// Extract the value outputting it in a text format.
     Value,
