@@ -7,6 +7,7 @@ use crate::{
 
 mod config;
 mod format;
+#[cfg(feature = "lint")]
 mod lint;
 #[cfg(feature = "lsp")]
 mod lsp;
@@ -24,24 +25,31 @@ impl<E: Environment> Taplo<E> {
         };
 
         match taplo.cmd {
-            TaploCommand::Format(fmt) => self.execute_format(fmt).await,
-            TaploCommand::Lsp { cmd } => {
-                #[cfg(feature = "lsp")]
-                {
-                    self.execute_lsp(cmd).await
-                }
-                #[cfg(not(feature = "lsp"))]
-                {
-                    let _ = cmd;
-                    Err(anyhow::anyhow!("the LSP is not part of this build, please consult the documentation about enabling the functionality"))
-                }
-            }
+            #[cfg(feature = "completions")]
+            TaploCommand::Completions { shell } => {
+                use anyhow::anyhow;
+                use clap::CommandFactory;
+                use clap_complete::{generate, shells::Shell};
+                use std::{io::stdout, str::FromStr};
 
+                let shell = Shell::from_str(&shell).map_err(|e| anyhow!(e))?;
+                generate(
+                    shell,
+                    &mut TaploArgs::command(),
+                    TaploArgs::command().get_bin_name().unwrap(),
+                    &mut stdout(),
+                );
+                Ok(())
+            }
+            TaploCommand::Config { cmd } => self.execute_config(cmd).await,
+            TaploCommand::Format(fmt) => self.execute_format(fmt).await,
+            TaploCommand::Get(cmd) => self.execute_get(cmd).await,
+            #[cfg(feature = "lint")]
+            TaploCommand::Lint(cmd) => self.execute_lint(cmd).await,
+            #[cfg(feature = "lsp")]
+            TaploCommand::Lsp { cmd } => self.execute_lsp(cmd).await,
             #[cfg(feature = "toml-test")]
             TaploCommand::TomlTest {} => self.execute_toml_test().await,
-            TaploCommand::Lint(cmd) => self.execute_lint(cmd).await,
-            TaploCommand::Config { cmd } => self.execute_config(cmd).await,
-            TaploCommand::Get(cmd) => self.execute_get(cmd).await,
         }
     }
 }
