@@ -7,14 +7,17 @@
     clippy::module_name_repetitions,
     clippy::missing_errors_doc,
     clippy::missing_panics_doc,
+    clippy::missing_fields_in_debug,
     clippy::similar_names,
-    clippy::too_many_lines
+    clippy::too_many_lines,
+    clippy::needless_continue
 )]
 
 pub mod config;
 pub mod convert;
 pub mod environment;
 pub mod log;
+#[cfg(feature = "schema")]
 pub mod schema;
 pub mod util;
 
