@@ -9,8 +9,11 @@ use jsonschema::{error::ValidationErrorKind, JSONSchema, SchemaResolver, Validat
 use parking_lot::Mutex;
 use regex::Regex;
 use serde_json::Value;
-use std::{borrow::Cow, sync::Arc};
-use taplo::dom::{self, node::Key, KeyOrIndex, Keys};
+use std::{borrow::Cow, num::NonZeroUsize, sync::Arc};
+use taplo::{
+    dom::{self, node::Key, KeyOrIndex, Keys},
+    rowan::TextRange,
+};
 use thiserror::Error;
 use tokio::sync::Semaphore;
 use url::Url;
@@ -20,15 +23,15 @@ pub mod cache;
 pub mod ext;
 
 pub mod builtins {
-    use reqwest::Url;
     use serde_json::Value;
     use std::sync::Arc;
+    use url::Url;
 
     pub const TAPLO_CONFIG_URL: &str = "taplo://taplo.toml";
 
     #[must_use]
     pub fn taplo_config_schema() -> Arc<Value> {
-        Arc::new(serde_json::to_value(&schemars::schema_for!(crate::config::Config)).unwrap())
+        Arc::new(serde_json::to_value(schemars::schema_for!(crate::config::Config)).unwrap())
     }
 
     #[must_use]
@@ -62,7 +65,7 @@ impl<E: Environment> Schemas<E> {
             concurrent_requests: Arc::new(Semaphore::new(10)),
             http,
             validators: Arc::new(Mutex::new(LruCache::with_hasher(
-                3,
+                NonZeroUsize::new(3).unwrap(),
                 ahash::RandomState::new(),
             ))),
         }
@@ -90,7 +93,7 @@ impl<E: Environment> Schemas<E> {
         schema_url: &Url,
         root: &dom::Node,
     ) -> Result<Vec<NodeValidationError>, anyhow::Error> {
-        let value = serde_json::to_value(&root)?;
+        let value = serde_json::to_value(root)?;
         self.validate(schema_url, &value)
             .await?
             .into_iter()
@@ -132,7 +135,7 @@ impl<E: Environment> Schemas<E> {
         // to fully validate according to a schema that has many nested references.
         loop {
             match validator.validate(value) {
-                Ok(_) => return Ok(Vec::new()),
+                Ok(()) => return Ok(Vec::new()),
                 Err(errors) => {
                     let errors: Vec<_> = errors
                         .map(|err| ValidationError {
@@ -248,7 +251,6 @@ impl<E: Environment> Schemas<E> {
             }
             None => {
                 let val = self.load_schema(&url).await?;
-                let val = val;
                 drop(self.cache.store(url, val.clone()));
                 Ok(val)
             }
@@ -368,14 +370,11 @@ impl<E: Environment> Schemas<E> {
 
         let include_self = schema["allOf"].is_null();
 
-        let key = match path.iter().next() {
-            Some(k) => k,
-            None => {
-                if include_self {
-                    schemas.push((full_path.clone(), Arc::new(schema.clone())));
-                }
-                return Ok(());
+        let Some(key) = path.iter().next() else {
+            if include_self {
+                schemas.push((full_path.clone(), Arc::new(schema.clone())));
             }
+            return Ok(());
         };
 
         let child_path = path.skip_left(1);
@@ -474,7 +473,7 @@ impl<E: Environment> Schemas<E> {
         for (path, schema) in schemas {
             self.collect_child_schemas(
                 schema_url,
-                &*schema,
+                &schema,
                 &path,
                 &Keys::empty(),
                 max_depth,
@@ -683,6 +682,13 @@ impl NodeValidationError {
         let mut keys = Keys::empty();
         let mut node = root.clone();
 
+        match &error.kind {
+            ValidationErrorKind::AdditionalProperties { unexpected } => {
+                keys = keys.extend(unexpected.iter().map(Key::from).map(KeyOrIndex::Key));
+            }
+            _ => {}
+        }
+
         'outer: for path in &error.instance_path {
             match path {
                 jsonschema::paths::PathChunk::Property(p) => match node {
@@ -709,6 +715,27 @@ impl NodeValidationError {
 
         Ok(Self { keys, node, error })
     }
+
+    #[must_use]
+    pub fn text_ranges(&self) -> Box<dyn Iterator<Item = TextRange> + '_> {
+        match self.error.kind {
+            ValidationErrorKind::AdditionalProperties { .. } => {
+                let include_children = false;
+
+                if self.keys.is_empty() {
+                    return Box::new(self.node.text_ranges(include_children));
+                }
+
+                Box::new(
+                    self.keys
+                        .clone()
+                        .into_iter()
+                        .flat_map(move |key| self.node.get(key).text_ranges(include_children)),
+                )
+            }
+            _ => Box::new(self.node.text_ranges(true)),
+        }
+    }
 }
 
 mod formats {
