@@ -49,7 +49,7 @@ pub struct ArcHashValue(pub Arc<Value>);
 
 impl Hash for ArcHashValue {
     fn hash<H: Hasher>(&self, state: &mut H) {
-        HashValue(&*self.0).hash(state);
+        HashValue(&self.0).hash(state);
     }
 }
 
@@ -62,13 +62,13 @@ impl PartialEq for ArcHashValue {
 #[derive(Eq)]
 pub struct HashValue<'v>(pub &'v Value);
 
-impl<'v> PartialEq for HashValue<'v> {
+impl PartialEq for HashValue<'_> {
     fn eq(&self, other: &Self) -> bool {
         self.0 == other.0
     }
 }
 
-impl<'v> Hash for HashValue<'v> {
+impl Hash for HashValue<'_> {
     fn hash<H: Hasher>(&self, state: &mut H) {
         match &self.0 {
             Value::Null => 0.hash(state),
@@ -109,9 +109,8 @@ impl Normalize for PathBuf {
 }
 
 pub(crate) fn normalize_str(s: &str) -> Cow<str> {
-    let percent_decoded = match percent_decode_str(s).decode_utf8().ok() {
-        Some(s) => s,
-        None => return s.into(),
+    let Some(percent_decoded) = percent_decode_str(s).decode_utf8().ok() else {
+        return s.into();
     };
 
     if cfg!(windows) {
@@ -121,16 +120,16 @@ pub(crate) fn normalize_str(s: &str) -> Cow<str> {
     }
 }
 
-#[cfg(not(target_arch = "wasm32"))]
+#[cfg(all(not(target_arch = "wasm32"), feature = "reqwest"))]
 #[tracing::instrument]
 pub fn get_reqwest_client(timeout: std::time::Duration) -> Result<reqwest::Client, reqwest::Error> {
     #[cfg(any(feature = "native-tls", feature = "rustls-tls"))]
     fn get_certs(
         mut builder: reqwest::ClientBuilder,
-        path: std::ffi::OsString,
+        path: &std::ffi::OsString,
     ) -> reqwest::ClientBuilder {
         fn get_cert(path: &Path) -> Result<reqwest::Certificate, anyhow::Error> {
-            let is_der = path.extension().map_or(false, |ext| ext == "der");
+            let is_der = path.extension().is_some_and(|ext| ext == "der");
             let buf = std::fs::read(path)?;
             tracing::info!(
                 "Found a custom CA {}. Reading the CA...",
@@ -165,7 +164,7 @@ pub fn get_reqwest_client(timeout: std::time::Duration) -> Result<reqwest::Clien
 
     let mut builder = reqwest::Client::builder().timeout(timeout);
     if let Some(path) = std::env::var_os("TAPLO_EXTRA_CA_CERTS") {
-        builder = get_certs(builder, path)
+        builder = get_certs(builder, &path);
     }
     builder.build()
 }
