@@ -46,18 +46,14 @@ pub async fn completion<E: Environment>(
         }
     };
 
-    let schema_association = match ws.schemas.associations().association_for(&document_uri) {
-        Some(ass) => ass,
-        None => return Ok(None),
+    let Some(schema_association) = ws.schemas.associations().association_for(&document_uri) else {
+        return Ok(None);
     };
 
     let position = p.text_document_position.position;
-    let offset = match doc.mapper.offset(Position::from_lsp(position)) {
-        Some(ofs) => ofs,
-        None => {
-            tracing::error!(?position, "document position not found");
-            return Ok(None);
-        }
+    let Some(offset) = doc.mapper.offset(Position::from_lsp(position)) else {
+        tracing::error!(?position, "document position not found");
+        return Ok(None);
     };
 
     let query = Query::at(&doc.dom, offset);
@@ -88,7 +84,7 @@ pub async fn completion<E: Environment>(
                         || s["type"] == "object"
                         || s["type"]
                             .as_array()
-                            .map_or(false, |arr| arr.iter().any(|v| v == "object"))
+                            .is_some_and(|arr| arr.iter().any(|v| v == "object"))
                 })
             }) {
             Ok(s) => s,
@@ -117,8 +113,7 @@ pub async fn completion<E: Environment>(
                 .filter(|(full_key, _, _)| match doc.dom.path(full_key) {
                     Some(n) => {
                         node.0 == *full_key
-                            || n.as_table()
-                                .map_or(false, |t| t.kind() == TableKind::Pseudo)
+                            || n.as_table().is_some_and(|t| t.kind() == TableKind::Pseudo)
                     }
                     None => true,
                 })
@@ -213,9 +208,7 @@ pub async fn completion<E: Environment>(
                 .into_iter()
                 // Filter out existing items.
                 .filter(|(full_key, _, _)| match doc.dom.path(full_key) {
-                    Some(n) => n
-                        .as_table()
-                        .map_or(false, |t| t.kind() == TableKind::Pseudo),
+                    Some(n) => n.as_table().is_some_and(|t| t.kind() == TableKind::Pseudo),
                     None => true,
                 })
                 .map(|(_, relative_keys, schema)| CompletionItem {
@@ -322,9 +315,7 @@ pub async fn completion<E: Environment>(
                     .into_iter()
                     // Filter out existing items.
                     .filter(|(full_key, _, _)| match doc.dom.path(full_key) {
-                        Some(n) => n
-                            .as_table()
-                            .map_or(false, |t| t.kind() == TableKind::Pseudo),
+                        Some(n) => n.as_table().is_some_and(|t| t.kind() == TableKind::Pseudo),
                         None => true,
                     })
                     .map(|(_, relative_keys, schema)| CompletionItem {
@@ -422,9 +413,7 @@ pub async fn completion<E: Environment>(
             .into_iter()
             // Filter out existing items.
             .filter(|(full_key, _, _)| match doc.dom.path(full_key) {
-                Some(n) => n
-                    .as_table()
-                    .map_or(false, |t| t.kind() == TableKind::Pseudo),
+                Some(n) => n.as_table().is_some_and(|t| t.kind() == TableKind::Pseudo),
                 None => true,
             })
             .map(|(_, relative_keys, schema)| CompletionItem {
@@ -615,7 +604,7 @@ fn add_value_completions(
                 }
                 "boolean" => {
                     completions.push(CompletionItem {
-                        label: r#"true"#.into(),
+                        label: r"true".into(),
                         kind: Some(CompletionItemKind::VALUE),
                         documentation: Some(Documentation::MarkupContent(MarkupContent {
                             kind: lsp_types::MarkupKind::Markdown,
@@ -625,13 +614,13 @@ fn add_value_completions(
                         text_edit: range.map(|range| {
                             CompletionTextEdit::Edit(TextEdit {
                                 range,
-                                new_text: r#"true$0"#.into(),
+                                new_text: r"true$0".into(),
                             })
                         }),
                         ..Default::default()
                     });
                     completions.push(CompletionItem {
-                        label: r#"false"#.into(),
+                        label: r"false".into(),
                         kind: Some(CompletionItemKind::VALUE),
                         documentation: Some(Documentation::MarkupContent(MarkupContent {
                             kind: lsp_types::MarkupKind::Markdown,
@@ -641,7 +630,7 @@ fn add_value_completions(
                         text_edit: range.map(|range| {
                             CompletionTextEdit::Edit(TextEdit {
                                 range,
-                                new_text: r#"false$0"#.into(),
+                                new_text: r"false$0".into(),
                             })
                         }),
                         ..Default::default()
@@ -649,7 +638,7 @@ fn add_value_completions(
                 }
                 "array" => {
                     completions.push(CompletionItem {
-                        label: r#"[]"#.into(),
+                        label: r"[]".into(),
                         kind: Some(CompletionItemKind::VALUE),
                         documentation: Some(Documentation::MarkupContent(MarkupContent {
                             kind: lsp_types::MarkupKind::Markdown,
@@ -659,7 +648,7 @@ fn add_value_completions(
                         text_edit: range.map(|range| {
                             CompletionTextEdit::Edit(TextEdit {
                                 range,
-                                new_text: r#"[$0]"#.into(),
+                                new_text: r"[$0]".into(),
                             })
                         }),
                         ..Default::default()
@@ -667,7 +656,7 @@ fn add_value_completions(
                 }
                 "object" => {
                     completions.push(CompletionItem {
-                        label: r#"{ }"#.into(),
+                        label: r"{ }".into(),
                         kind: Some(CompletionItemKind::VALUE),
                         documentation: Some(Documentation::MarkupContent(MarkupContent {
                             kind: lsp_types::MarkupKind::Markdown,
@@ -677,7 +666,7 @@ fn add_value_completions(
                         text_edit: range.map(|range| {
                             CompletionTextEdit::Edit(TextEdit {
                                 range,
-                                new_text: r#"{ $0 }"#.into(),
+                                new_text: r"{ $0 }".into(),
                             })
                         }),
                         ..Default::default()
